# Generated by Django 3.2.15 on 2022-09-19 17:55

import django.db.models.deletion
from django.db import migrations, models
from django.forms.models import model_to_dict


def migrate_activity_material(apps, schema_editor):
    """Migrate the activity material to activity material relation"""
    ActivityMaterial = apps.get_model("activities", "ActivityMaterial")
    ActivityMaterialRelation = apps.get_model(
        "activities", "ActivityMaterialRelation"
    )
    for material in list(ActivityMaterial.objects.all()):
        ActivityMaterialRelation.objects.create(
            material=material.material_ptr,
            activity=material.activity,
            members_only=material.members_only,
        )
        material.delete(keep_parents=True)


def undo_migrate_activity_material(apps, schema_editor):
    """Migrate the activity material relation to activity material"""
    ActivityMaterial = apps.get_model("activities", "ActivityMaterial")
    ActivityMaterialRelation = apps.get_model(
        "activities", "ActivityMaterialRelation"
    )
    for materialrelation in list(ActivityMaterialRelation.objects.all()):
        material = materialrelation.material
        kws = model_to_dict(materialrelation)
        kws.pop("material")
        kws.update(model_to_dict(material))
        kws["user"] = material.user
        kws["category"] = material.category
        kws["license"] = material.license
        kws["date_created"] = material.date_created
        ActivityMaterial.objects.create(material_ptr=material, **kws)


class Migration(migrations.Migration):

    dependencies = [
        ("uploaded_material", "0009_alter_material_uuid"),
        ("activities", "0013_activitymateriallistpluginmodel"),
    ]

    operations = [
        migrations.CreateModel(
            name="ActivityMaterialRelation",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "members_only",
                    models.BooleanField(
                        default=False,
                        help_text="Make this material available for members only?",
                    ),
                ),
                (
                    "activity",
                    models.ForeignKey(
                        help_text="The related group in the community that this material belongs to.",
                        on_delete=django.db.models.deletion.CASCADE,
                        to="activities.activity",
                        verbose_name="Working Group/Project Group",
                    ),
                ),
                (
                    "material",
                    models.ForeignKey(
                        help_text="The material that this relation corresponds to.",
                        on_delete=django.db.models.deletion.CASCADE,
                        to="uploaded_material.material",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.RunPython(
            migrate_activity_material, undo_migrate_activity_material
        ),
        migrations.DeleteModel(
            name="ActivityMaterial",
        ),
    ]
