# Generated by Django 3.2.15 on 2023-01-27 08:35

from django.db import migrations, models


def update_view_permissions(apps, schema_editor):
    """Make material available to members prior to removing members_only."""
    ActivityMaterialRelation = apps.get_model(
        "activities", "ActivityMaterialRelation"
    )
    Group = apps.get_model("auth", "Group")

    for relation in ActivityMaterialRelation.objects.filter(
        members_only=False
    ):
        members_group = Group.objects.get_or_create(name="Community members")[
            0
        ]
        relation.material.group_view_permission.add(members_group)


def set_material_permissions(apps, schema_editor):
    ActivityMaterialRelation = apps.get_model(
        "activities", "ActivityMaterialRelation"
    )
    ContentType = apps.get_model("contenttypes", "ContentType")
    UserObjectPermission = apps.get_model("guardian", "UserObjectPermission")
    GroupObjectPermission = apps.get_model("guardian", "GroupObjectPermission")
    Permission = apps.get_model("auth", "Permission")
    Material = apps.get_model("uploaded_material", "Material")

    material_ct = ContentType.objects.get_for_model(Material)

    permissions = []
    for codename in [
        "view_material",
        "change_material",
        "delete_material",
    ]:
        try:
            permissions.append(
                Permission.objects.get(
                    codename=codename, content_type=material_ct
                )
            )
        except Permission.DoesNotExist:
            pass

    for relation in ActivityMaterialRelation.objects.filter(
        symbolic_relation=False
    ):
        relation.is_default = True
        relation.save()
        GroupObjectPermission.objects.get_or_create(
            permission=permissions[0],
            content_type=material_ct,
            object_pk=relation.material.pk,
            group=relation.activity.activitygroup,
        )
        for leader in relation.activity.leaders.filter(user__isnull=False):
            for permission in permissions:
                UserObjectPermission.objects.get_or_create(
                    permission=permission,
                    content_type=material_ct,
                    object_pk=relation.material.pk,
                    user=leader.user,
                )


class Migration(migrations.Migration):

    dependencies = [
        ("activities", "0018_auto_20221223_1541"),
    ]

    operations = [
        migrations.RunPython(
            update_view_permissions, migrations.RunPython.noop
        ),
        migrations.RemoveField(
            model_name="activitymaterialrelation",
            name="members_only",
        ),
        migrations.AddField(
            model_name="activitymaterialrelation",
            name="is_default",
            field=models.BooleanField(
                default=False,
                help_text="Is this relation the default entry point?",
            ),
        ),
        migrations.AddField(
            model_name="activitymaterialrelation",
            name="symbolic_relation",
            field=models.BooleanField(
                default=False,
                help_text="If this is a symbolic relation, this relation does not have any influences on the permissions.",
            ),
        ),
        migrations.RunPython(
            set_material_permissions, migrations.RunPython.noop
        ),
    ]
