# Generated by Django 3.2.15 on 2022-12-23 15:38

from django.db import migrations


def set_channel_permissions(apps, schema_editor):
    TopicChannelRelation = apps.get_model("topics", "TopicChannelRelation")
    Topic = apps.get_model("topics", "Topic")
    ContentType = apps.get_model("contenttypes", "ContentType")
    UserObjectPermission = apps.get_model("guardian", "UserObjectPermission")
    Permission = apps.get_model("auth", "Permission")
    Channel = apps.get_model("chats", "Channel")

    channel_ct = ContentType.objects.get_for_model(Channel)
    topic_ct = ContentType.objects.get_for_model(Topic)

    permissions = []
    for codename in [
        "view_channel",
        "change_channel",
        "delete_channel",
        "start_thread",
        "post_comment",
    ]:
        try:
            permissions.append(
                Permission.objects.get(
                    codename=codename, content_type=channel_ct
                )
            )
        except Permission.DoesNotExist:
            pass

    for relation in TopicChannelRelation.objects.filter(
        symbolic_relation=False
    ):
        for perm_map in UserObjectPermission.objects.filter(
            object_pk=relation.topic.pk,
            content_type=topic_ct,
            permission__codename="change_topic",
            permission__content_type=topic_ct,
        ):
            for permission in permissions:
                UserObjectPermission.objects.get_or_create(
                    permission=permission,
                    content_type=channel_ct,
                    object_pk=relation.channel.pk,
                    user=perm_map.user,
                )


class Migration(migrations.Migration):

    dependencies = [
        (
            "chats",
            "0006_channelmaterialrelation_unique_channel_relation_for_material",
        ),
        (
            "topics",
            "0014_topicmaterialrelation_unique_topic_relation_for_material",
        ),
    ]

    operations = [
        migrations.RunPython(
            set_channel_permissions, migrations.RunPython.noop
        )
    ]
